// =======================================================================
// This file is part of sswriter (Sky Status Writer).
//
// Copyright 2008  Jonathan 'Sky' Squirawski <webmaster@sky-siteweb.com>
// 
// SSWriter is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// SSWriter is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with SSWriter.  If not, see <http://www.gnu.org/licenses/>.
// -----------------------------------------------------------------------
//
//   File for acpi parsing.
// =======================================================================

#ifndef __ACPI_PARSING_H__
#define __ACPI_PARSING_H__

#include "sswriter_std.h"

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <time.h>
#include <ctype.h>


#include <math.h>

// POSIX / BSD / SYS V
#include <sys/socket.h>
#include <unistd.h>

// Linux specific
#define IFNAMSIZ 16
#include <linux/types.h>
#include <sys/types.h>
#include <linux/if.h>
#include <linux/wireless.h>
#include <sys/ioctl.h>
#include <locale.h>

#ifdef __WITH_XKB__
#include <X11/XKBlib.h>
#endif


#define BAT "/proc/acpi/battery/BAT"
#define BAT_STATE "/state"
#define BAT_INFO "/info"
#define MEM_INFOS "/proc/meminfo"
#define CPU_INFOS "/proc/cpuinfo"
#define CPUFREQ_BASE "/sys/devices/system/cpu/cpu"
#define CPUFREQ_MAX "/cpufreq/scaling_max_freq"
#define CPUFREQ_CUR "/cpufreq/scaling_cur_freq"
#define THRM_ZONE "/proc/acpi/thermal_zone/"
#define THRM_FILE "/temperature"

#define WIRELESS_CHECK_BASE "/sys/class/net/"
#define WIRELESS_CHECK_END "/wireless/status"
#define NETWORK_FOLDER "/sys/class/net/"
#define NETWORK_DOWN "/statistics/rx_bytes"
#define NETWORK_UP "/statistics/tx_bytes"
#define WIRELESS_INFOS "/proc/net/wireless"

#define HWMON_THRM "/sys/class/hwmon/hwmon%u/device/temp%u_input"

unsigned int insert_date(char *sbuff, unsigned int len,
      const char *date_format);
unsigned int insert_battery_state(char *sbuff, unsigned int len,
      unsigned int number,
      unsigned int warn_limit, int *warn);
unsigned int insert_mem_state(char *sbuff, unsigned int len);
unsigned int insert_swap_state(char *sbuff, unsigned int len);
unsigned int insert_cpu_freq(char *sbuff, unsigned int len,
      unsigned int number);
unsigned int insert_temperature(char *sbuff, unsigned int len,
      const char *sensor_name);
unsigned int insert_sensor_temp(char *sbuff, unsigned int len,
      unsigned int sensor_id, unsigned int temp_id);

#ifdef __WITH_XKB__
unsigned int insert_kbd_numlock(char *sbuff, unsigned int len);
#endif

void get_cpufreq_freq(unsigned int number, int *fcur, int *fpercent);
void get_network_device(char **devices, unsigned int nb_devices,
      char *name, unsigned int name_len, double *in, double *out);
double compute_device_rate(double t_time, double t_last_time,
      unsigned long t_bytes, unsigned long t_last_bytes);
int get_wireless_quality(const char *device);

unsigned int insert_fortune(char *sbuff, unsigned int len, const char* filename);

#endif
